@@ -15,10 +15,10 @@ class TestBecomeUserWithoutBecome(unittest.TestCase):
     def test_file_positive(self) -> None:
         success = 'examples/playbooks/become-user-without-become-success.yml'
         good_runner = Runner(success, rules=self.collection)
-        self.assertEqual([], good_runner.run())
+        assert [] == good_runner.run()
 
     def test_file_negative(self) -> None:
         failure = 'examples/playbooks/become-user-without-become-failure.yml'
         bad_runner = Runner(failure, rules=self.collection)
         errs = bad_runner.run()
-        self.assertEqual(3, len(errs))
+        assert len(errs) == 3
